pub struct CancelCapacityReservationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CancelCapacityReservation.
Cancels the capacity reservation with the specified name. Cancelled reservations remain in your account and will be deleted 45 days after cancellation. During the 45 days, you cannot re-purpose or reuse a reservation that has been cancelled, but you can refer to its tags and view it for historical reference.
Implementations
Sourceimpl CancelCapacityReservationFluentBuilder
impl CancelCapacityReservationFluentBuilder
Sourcepub fn as_input(&self) -> &CancelCapacityReservationInputBuilder
pub fn as_input(&self) -> &CancelCapacityReservationInputBuilder
Access the CancelCapacityReservation as a reference.
Sourcepub async fn send(
self,
) -> Result<CancelCapacityReservationOutput, SdkError<CancelCapacityReservationError, HttpResponse>>
pub async fn send( self, ) -> Result<CancelCapacityReservationOutput, SdkError<CancelCapacityReservationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CancelCapacityReservationOutput, CancelCapacityReservationError, Self>
pub fn customize( self, ) -> CustomizableOperation<CancelCapacityReservationOutput, CancelCapacityReservationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the capacity reservation to cancel.